@@ -8,5 +8,4 @@ export SXMO_POWER_BUTTON="0:0:pm8941_pwrkey"
 export SXMO_VOLUME_BUTTON="1:1:GPIO_Buttons 0:0:pm8941_resin"
 export SXMO_ROTATION_GRAVITY="500"
 export SXMO_ROTATION_THRESHOLD="60"
-export SXMO_LED_WHITE_TYPE="kbd_backlight"
-export SXMO_SYS_FILES="/sys/power/state /sys/power/mem_sleep /sys/bus/usb/drivers/usb/unbind /sys/bus/usb/drivers/usb/bind /dev/rtc0"
+export SXMO_SWAY_SCALE="2"
