@@ -1,10 +1,10 @@
 #!/bin/sh
+# SPDX-License-Identifier: AGPL-3.0-only
+# Copyright 2022 Sxmo Contributors
 
-# shellcheck disable=SC2034
-SXMO_NO_ICONS=1 #just to make it a bit faster
 # include common definitions
 # shellcheck source=scripts/core/sxmo_common.sh
-. "$(dirname "$0")/sxmo_common.sh"
+. sxmo_common.sh
 
 isopen() {
 	if [ -z "$KEYBOARD" ]; then
@@ -30,7 +30,9 @@ close() {
 if [ "$1" = "toggle" ]; then
 	close || open
 elif [ "$1" = "close" ]; then
-	close
+	if isopen; then
+		close
+	fi
 elif [ "$1" = "isopen" ]; then
 	isopen || exit 1
 else
