@@ -63,7 +63,7 @@ checkforlostmms() {
 		done < "$ALL_MMS_TEMP"
 		if [ "$1" = "--force" ]; then
 			info "Finished."
-		else 
+		else
 			info "Run $0 checkforlostmms --force to process (if sent or received) or delete (if expired or draft)."
 		fi
 	fi
@@ -199,7 +199,7 @@ processmms() {
 		fi
 
 		if grep -q screenoff "$SXMO_STATE"; then
-			sxmo_hook_lock.sh
+			sxmo_state.sh set lock
 		fi
 
 		if [ "$NUM_RECIPIENTS" -gt 1 ]; then
@@ -212,6 +212,6 @@ processmms() {
 
 }
 
-sxmo_wakelock.sh lock mms_processing 30s
+sxmo_wakelock.sh lock sxmo_mms_processing 30s
 "$@"
-sxmo_wakelock.sh unlock mms_processing
+sxmo_wakelock.sh unlock sxmo_mms_processing
