@@ -2,21 +2,22 @@
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
+# shellcheck source=scripts/core/sxmo_common.sh
+. sxmo_common.sh
+
 envvars() {
 	export SXMO_WM=dwm
+	export XDG_CURRENT_DESKTOP=dwm
 	# shellcheck disable=SC2086
-	command -v $TERMCMD "" >/dev/null || export TERMCMD="st"
+	command -v $SXMO_TERMINAL "" >/dev/null || export SXMO_TERMINAL="st -e"
 	command -v "$KEYBOARD" >/dev/null || defaultkeyboard
 	[ -z "$MOZ_USE_XINPUT2" ] && export MOZ_USE_XINPUT2=1
 }
 
 defaults() {
-	xmodmap /usr/share/sxmo/appcfg/xmodmap_caps_esc
+	xmodmap "$(xdg_data_path sxmo/appcfg/xmodmap_caps_esc)"
 	xsetroot -mod 29 29 -fg '#0b3a4c' -bg '#082430'
 	xset s off -dpms
-	for xr in /usr/share/sxmo/appcfg/*.xr; do
-		xrdb -merge "$xr"
-	done
 	[ -e "$HOME"/.Xresources ] && xrdb -merge "$HOME"/.Xresources
 	SCREENWIDTH=$(xrandr | grep "Screen 0" | cut -d" " -f 8)
 	SCREENHEIGHT=$(xrandr | grep "Screen 0" | cut -d" " -f 10 | tr -d ",")
@@ -43,43 +44,12 @@ with_dbus() {
 	exec dwm
 }
 
-start() {
-	if [ -z "$DBUS_SESSION_BUS_ADDRESS" ]; then
-		dbus-run-session -- "$0" "with_dbus"
-	else
-		# with_dbus calls exec because dbus-run-session starts it in a
-		# new shell, but we need to keep this shell; start in a subshell
-		( with_dbus )
-	fi
-}
-
 cleanup() {
-	sxmo_daemons.sh stop all
+	sxmo_jobs.sh stop all
 	pkill svkbd
 	pkill dmenu
+	pkill superd
 }
 
-init() {
-	# shellcheck source=scripts/core/sxmo_common.sh
-	. /etc/profile.d/sxmo_init.sh
-
-	_sxmo_load_environments
-	_sxmo_prepare_dirs
-	envvars
-	sxmo_migrate.sh sync
-
-	defaults
-
-	# shellcheck disable=SC1090,SC1091
-	. "$XDG_CONFIG_HOME/sxmo/profile"
-
-	start
-	cleanup
-	sxmo_hook_stop.sh
-}
-
-if [ -z "$1" ]; then
-	init
-else
-	"$1"
-fi
+# shellcheck source=scripts/core/sxmo_init.sh
+. sxmo_init.sh
