@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 46ebbcaee90873fbe0c4aab1e97c2044
+# configversion: cce959504ab84b8fa77bc02288f0f66e
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -22,6 +22,7 @@ if [ "$1" = "enable" ]; then
 
 	# Add other things here, e.g., volume boosters
 
+	sxmo_modemaudio.sh is_disabled_speaker && sxmo_modemaudio.sh is_unmuted_mic
 # Phonecall ended
 elif [ "$1" = "disable" ]; then
 	sxmo_log "Attempting hack to get things just right."
@@ -31,4 +32,5 @@ elif [ "$1" = "disable" ]; then
 
 	# Add other things here, e.g., volume boosters
 
+	sxmo_modemaudio.sh is_enabled_speaker
 fi
